Modeling and Machine Learning
=============================


Models
---------------

.. autosummary::
   :toctree: _autosummary_models
   :nosignatures:
   :recursive:

   cedalion.models.glm
   cedalion.math.ar_model
   
Decomposition Methods
---------------------

.. autosummary::
    :toctree: _autosummary_decomp
    :recursive:
    :nosignatures:

    cedalion.sigdecomp.ERBM
    cedalion.sigdecomp.ICA_EBM

Examples
--------

.. nbgallery::
   :glob:

   ../examples/machine_learning/*
   ../examples/modeling/*